TempoReceipt

Type Alias TempoReceipt 

pub type TempoReceipt<L = Log> = EthereumReceipt<TempoTxType, L>;
Available on crate feature reth only.
Tempo receipt.

Re-export from reth_ethereum_primitives so that the rest of the workspace crates see a single type that satisfies both alloy trait bounds and reth trait bounds.

Shadows the alloy-only alias in lib.rs when the reth feature is active.

Aliased Type

pub struct TempoReceipt<L = Log> {
    pub tx_type: TempoTxType,
    pub success: bool,
    pub cumulative_gas_used: u64,
    pub logs: Vec<L>,
}

Fields

tx_type: TempoTxType

Receipt type.

success: bool

If transaction is executed successfully.

This is the statusCode

cumulative_gas_used: u64

Gas used

logs: Vec<L>

Log send from contracts.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 40 bytes